.. _api:

API
===

The Translate Toolkit provides several modules for programmers to build
their own tools.

Module overview
----------------

The following will give you an idea about what each module is capable of.

convert
^^^^^^^
.. automodule:: translate.convert
   :noindex:

filters
^^^^^^^
.. automodule:: translate.filters
   :noindex:

lang
^^^^
.. automodule:: translate.lang
   :noindex:

misc
^^^^
.. automodule:: translate.misc
   :noindex:

search
^^^^^^
.. automodule:: translate.search
   :noindex:

services
^^^^^^^^
.. automodule:: translate.services
   :noindex:

storage
^^^^^^^
.. automodule:: translate.storage
   :noindex:

tools
^^^^^
.. automodule:: translate.tools
   :noindex:


Module list
------------

All the modules included in the Translated Toolkit are listed here.

.. toctree::
   :maxdepth: 3

   convert
   filters
   lang
   misc
   search
   services
   storage
   tools
